@@ -1,6 +1,7 @@
 from mo_future import text
 
+ANY = text("*/*")
 BINARY = text("application/octet-stream")
 GZIP = text("application/gzip")
-JSON = text("application/json")
+JSON = text("application/json; charset=utf-8")
 ZIP = text("application/zip")
